function install-kubernetes {
        Param(
                [Parameter(Mandatory=$true)]
                $NodeIP,
                $ClusterCIDR = "10.244.0.0/16",
                $ServiceCIDR = "10.96.0.0/12",
                $KubeDNSServiceIP = "10.96.0.10",
                $Lagringsplassering = "\\WIN-HOST\Nettverksdelt"
        )

        #Sjekker at docker er installert og henter pause-image for kubernetes
        Write-Verbose "Sjekker at docker er installert"
        Start-Service docker
        If (-Not ($?)) {
                Write-Error "Docker kunne ikke startes. Installer dette før du går videre"
                throw
        }
        Write-Verbose "Henter Pause-image for Kubernetes"
        docker pull mcr.microsoft.com/windows/nanoserver:1809 1>$null
        docker tag mcr.microsoft.com/windows/nanoserver:1809 microsoft/nanoserver:latest
        docker run microsoft/nanoserver:latest 1>$null

        #Laster ned Kubernetes exe-filer
        Write-Output "Henter Kubernetes exe-filer"
        New-Item -ItemType "directory" -Path "c:\k"  1>$null
        Set-Location "C:\k"
        Invoke-WebRequest -Uri "https://dl.k8s.io/v1.14.0/kubernetes-node-windows-amd64.tar.gz" -OutFile ".\kubernetes-node-windows-amd64.tar.gz"

        Write-Verbose "Pakker ut filene"
        tar -xzvf ".\kubernetes-node-windows-amd64.tar.gz" 2>$null
        Copy-Item -Path ".\kubernetes\node\bin\*" -Destination ".\"

        Write-Verbose "Fjerner installasjonsfiler"
        Remove-Item -Path ".\kubernetes" -Force -Recurse
        Remove-Item -Path ".\kubernetes-node-windows-amd64.tar.gz" -Force
        Write-Verbose "Fjernet unødvendige filer, starter installasjon"

        #Henter config-fil fra Host-maskin
        Write-Verbose "Henter Config-fil fra Lagringsplassering"
        Copy-Item -Path "$Lagringsplassering\config" -Destination ".\config"

        #Flannel https://github.com/Microsoft/SDN/tree/master/Kubernetes/flannel
        #Henter installasjonsfiler for flannel
        Write-Output "Henter installasjonsfiler for flannel"
        Invoke-WebRequest -Uri "https://github.com/coreos/flannel/releases/download/v0.11.0/flanneld.exe" -OutFile ".\flanneld.exe"
        Invoke-WebRequest -Uri "https://raw.githubusercontent.com/Microsoft/SDN/master/Kubernetes/flannel/start.ps1" -OutFile ".\start.ps1"

        #Henter NSSM, dette sørger for at alle tjenester kjøres som windows-service slik at det startes sammen med OS-et
        Write-Output "Henter NSSM"
        Invoke-WebRequest -Uri "https://nssm.cc/release/nssm-2.24.zip" -OutFile ".\nssm.zip"
        Expand-Archive ".\nssm.zip" -DestinationPath ".\nssm"
        Copy-Item -Path ".\nssm\nssm-2.24\win64\nssm.exe" -Destination ".\nssm.exe"
        Write-Verbose "Fjerner NSSM installasjonsfiler"
        Remove-Item -Path ".\nssm" -Force -Recurse
        Remove-Item -Path ".\nssm.zip" -Force

        #Setter opp Kubernetes som Windows-services (Bruker NSSM)
        #https://docs.microsoft.com/en-us/virtualization/windowscontainers/kubernetes/kube-windows-services?tabs=ManagementIP
        Write-Verbose "Registrerer kubernetes program som windows services"
        Invoke-WebRequest -Uri "https://raw.githubusercontent.com/Microsoft/SDN/master/Kubernetes/flannel/register-svc.ps1" -OutFile ".\register-svc.ps1"
        #Legger til --read-only-port 10255 p� kubelet
        (Get-Content .\register-svc.ps1).Replace("--cni-conf-dir=c:\k\cni\config","--cni-conf-dir=c:\k\cni\config --read-only-port 10255") | Set-Content .\register-svc.ps1
        .\register-svc.ps1 -NetworkMode "l2bridge" -ManagementIP $NodeIP -ClusterCIDR $ClusterCIDR -KubeDNSServiceIP $KubeDNSServiceIP -LogDir "c:\k\KubeLogs"

        #Starter installasjonsscript fra Microsoft
        Write-Output "Kobler noden til clusteret"
        Chcp 65001
        .\start.ps1 -ManagementIP $NodeIP -ClusterCIDR $ClusterCIDR -NetworkMode "l2bridge" -ServiceCIDR $ServiceCIDR -KubeDNSServiceIP $KubeDNSServiceIP

}
